@@ -27,6 +27,10 @@
 *                               CDF_getzVarsRecordData, CDF_putrVarsRecordData,
 *                               CDF_putzVarsRecordData.
 *   V3.1  26-May-05, M Liu      Initial version (for CDF V3.1).
+*   V3.2  23-Oct-08, M Liu      Modified CDF_getrVarsRecordData,
+*                               CDF_getzVarsRecordData, CDF_putrVarsRecordData,
+*                               CDF_putzVarsRecordData to use the number of
+*                               passed variables to allocate buffers.
 *
 ******************************************************************************/
 
@@ -2734,7 +2738,7 @@ Int32     *status;              /* Out: CDF status code. */
 {
   long num_varsT = (long) *num_vars;
   long recNumT = (long) (*rec_num - 1);
-  long varNumsT[CDF_MAX_DIMS];
+  long *varNumsT;
   int i;
 
   if (*num_vars < 1) {
@@ -2742,6 +2746,12 @@ Int32     *status;              /* Out: CDF status code. */
     return;
   }
 
+  varNumsT = cdf_AllocateMemory (*num_vars*sizeof(long), NULL);
+  if (varNumsT == NULL) {
+    *status = BAD_MALLOC;
+    return;
+  }
+
   for (i = 0; i < *num_vars; i++) varNumsT[i] = (long) varNums[i] - 1;
 
   *status = (Int32) CDFlib (SELECT_, CDF_, Int32ToCDFid(*id),
@@ -2751,6 +2761,7 @@ Int32     *status;              /* Out: CDF status code. */
   *status = (Int32) CDFlib (SELECT_, rVARs_RECNUMBER_, recNumT,
                             GET_, rVARs_RECDATA_, num_varsT, varNumsT, buffptr,
                             NULL_);
+  cdf_FreeMemory (varNumsT, NULL);
   return;
 
 }
@@ -2777,7 +2788,7 @@ Int32     *status;              /* Out: CDF status code. */
 {
   long num_varsT = (long) *num_vars;
   long recNumT = (long) (*rec_num - 1);
-  long varNumsT[CDF_MAX_DIMS];
+  long *varNumsT;
   int i;
 
   if (*num_vars < 1) {
@@ -2785,6 +2796,12 @@ Int32     *status;              /* Out: CDF status code. */
     return;
   }
 
+  varNumsT = cdf_AllocateMemory (*num_vars*sizeof(long), NULL);
+  if (varNumsT == NULL) {
+    *status = BAD_MALLOC;
+    return;
+  }
+
   for (i = 0; i < *num_vars; i++) varNumsT[i] = (long) varNums[i] - 1;
 
   *status = (Int32) CDFlib (SELECT_, CDF_, Int32ToCDFid(*id),
@@ -2794,6 +2811,8 @@ Int32     *status;              /* Out: CDF status code. */
   *status = (Int32) CDFlib (SELECT_, zVARs_RECNUMBER_, recNumT,
                             GET_, zVARs_RECDATA_, num_varsT, varNumsT, buffptr,
                             NULL_);
+  cdf_FreeMemory (varNumsT, NULL);
+
   return;
 
 }
@@ -2820,7 +2839,7 @@ Int32     *status;              /* Out: CDF status code. */
 {
   long num_varsT = (long) *num_vars;
   long recNumT = (long) (*rec_num - 1);
-  long varNumsT[CDF_MAX_DIMS];
+  long *varNumsT;
   int i;
 
   if (*num_vars < 1) {
@@ -2828,6 +2847,12 @@ Int32     *status;              /* Out: CDF status code. */
     return;
   }
 
+  varNumsT = cdf_AllocateMemory (*num_vars*sizeof(long), NULL);
+  if (varNumsT == NULL) {
+    *status = BAD_MALLOC;
+    return;
+  }
+
   *status = (Int32) CDFlib (SELECT_, CDF_, Int32ToCDFid(*id),
                             NULL_);
   if (StatusBAD(*status)) return;
@@ -2837,6 +2862,7 @@ Int32     *status;              /* Out: CDF status code. */
   *status = (Int32) CDFlib (SELECT_, rVARs_RECNUMBER_, recNumT,
                             PUT_, rVARs_RECDATA_, num_varsT, varNumsT, buffptr,
                             NULL_);
+  cdf_FreeMemory (varNumsT, NULL);
   return;
 }
 
@@ -2862,7 +2888,7 @@ Int32     *status;              /* Out: CDF status code. */
 {
   long num_varsT = (long) *num_vars;
   long recNumT = (long) (*rec_num - 1);
-  long varNumsT[CDF_MAX_DIMS];
+  long *varNumsT;
   int i;
 
   if (*num_vars < 1) {
@@ -2870,6 +2896,12 @@ Int32     *status;              /* Out: CDF status code. */
     return;
   }
 
+  varNumsT = cdf_AllocateMemory (*num_vars*sizeof(long), NULL);
+  if (varNumsT == NULL) {
+    *status = BAD_MALLOC;
+    return;
+  }
+
   *status = (Int32) CDFlib (SELECT_, CDF_, Int32ToCDFid(*id),
                             NULL_);
   if (StatusBAD(*status)) return;
@@ -2879,6 +2911,7 @@ Int32     *status;              /* Out: CDF status code. */
   *status = (Int32) CDFlib (SELECT_, zVARs_RECNUMBER_, recNumT,
                             PUT_, zVARs_RECDATA_, num_varsT, varNumsT, buffptr,
                             NULL_);
+  cdf_FreeMemory (varNumsT, NULL);
   return;
 }
 
@@ -2904,18 +2937,25 @@ Int32     *status;              /* Out: CDF status code. */
 {
   long num_varsT = (long) *num_vars;
   long recNumT = (long) (*rec_num - 1);
-  long varNumsT[CDF_MAX_DIMS];
+  long *varNumsT;
   int i;
 
   *status = (Int32) CDFlib (SELECT_, CDF_, Int32ToCDFid(*id),
                             NULL_);
   if (StatusBAD(*status)) return;
 
+  varNumsT = cdf_AllocateMemory (*num_vars*sizeof(long), NULL);
+  if (varNumsT == NULL) {
+    *status = BAD_MALLOC;
+    return;
+  }
+
   for (i = 0; i < *num_vars; i++) varNumsT[i] = (long) varNums[i] - 1;
 
   *status = (Int32) CDFlib (SELECT_, zVARs_RECNUMBER_, recNumT,
                             GET_, zVARs_RECDATA_, num_varsT, varNumsT, buffptr,
                             NULL_);
+  cdf_FreeMemory (varNumsT, NULL);
   return;
 
 }
@@ -2942,7 +2982,7 @@ Int32     *status;              /* Out: CDF status code. */
 {
   long num_varsT = (long) *num_vars;
   long recNumT = (long) (*rec_num - 1);
-  long varNumsT[CDF_MAX_DIMS];
+  long *varNumsT;
   int i;
 
   if (*num_vars < 1) {
@@ -2954,11 +2994,18 @@ Int32     *status;              /* Out: CDF status code. */
                             NULL_);
   if (StatusBAD(*status)) return;
 
+  varNumsT = cdf_AllocateMemory (*num_vars*sizeof(long), NULL);
+  if (varNumsT == NULL) {
+    *status = BAD_MALLOC;
+    return;
+  }
+
   for (i = 0; i < *num_vars; i++) varNumsT[i] = (long) varNums[i] - 1;
 
   *status = (Int32) CDFlib (SELECT_, zVARs_RECNUMBER_, recNumT,
                             PUT_, zVARs_RECDATA_, num_varsT, varNumsT, buffptr,
                             NULL_);
+  cdf_FreeMemory (varNumsT, NULL);
   return;
 }
 
