@@ -21,6 +21,9 @@
 *                               in READONLYon mode.
 *   V3.2a 11-Apr-08, M Liu      Modified Read32s to eliminate the potential 
 *                               buffer overflow.
+*   V3.2b 15-Sep-08, M Liu      Modified ReadAEDRList64 to pass in the number of
+*                               entries to set up the list, not just the last
+*                               entry number.  
 *
 ******************************************************************************/
 
@@ -1623,10 +1626,12 @@ STATICforIDL CDFstatus ReadADRList (vFILE *fp)
       ***********************************************************************/
       pStatus = ReadAEDRList(fp, &(fp->ADRList[i]->grAEDRList),
                              fp->ADRList[i]->AgrEDRhead,
+                             fp->ADRList[i]->NgrEntries,
                              fp->ADRList[i]->MAXgrEntry);
       if (pStatus != CDF_OK) return pStatus;
       pStatus = ReadAEDRList(fp, &(fp->ADRList[i]->zAEDRList),
                              fp->ADRList[i]->AzEDRhead,
+                             fp->ADRList[i]->NzEntries,
                              fp->ADRList[i]->MAXzEntry);
       if (pStatus != CDF_OK) return pStatus;
   };
@@ -1634,20 +1639,22 @@ STATICforIDL CDFstatus ReadADRList (vFILE *fp)
 }
 
 /******************************************************************************
-* ReadAEDRList64.
+* ReadAEDRList.
 * Reads the set of entrys (zENTRYs or grENTRYs) associated with an attribute
 * into a list indexed by the entry number. If there is no entry for a particular
 * index (i.e., there is no entry for the associated variable/attribute
 * pair), the list entry is NULL.
 ******************************************************************************/
 STATICforIDL CDFstatus ReadAEDRList (vFILE *fp, 
-                                       struct AEDRstructExt ***AEDRList, 
-                                       Int32 AEDRHead, Int32 MaxEntry)
+                                     struct AEDRstructExt ***AEDRList, 
+                                     Int32 AEDRHead, 
+                                     Int32 NumEntries,
+                                     Int32 MaxEntry)
 {
   CDFstatus pStatus = CDF_OK;
   Int32 NxtAEDR = AEDRHead;
   struct AEDRstructExt *TempAEDR;
-  int LastAEDRNum = -1;
+  int iEntries;
   int i;
   /**************************************************************************
   * Allocate memory for the list and initialize each entry to NULL.
@@ -1667,11 +1674,12 @@ STATICforIDL CDFstatus ReadAEDRList (vFILE *fp,
   {
       (*AEDRList)[i] = NULL;
   };
+  iEntries = 0;
   /***************************************************************************
   * Allocate memory for each AEDR, read each AEDR, and assign them to the list
   * by entry number.
   ***************************************************************************/
-  while (NxtAEDR != 0 && LastAEDRNum != MaxEntry)
+  while (NxtAEDR != 0 && iEntries != NumEntries)
   {
       TempAEDR = cdf_AllocateMemory(sizeof(struct AEDRstructExt), NULL);
       if (TempAEDR == NULL) return BAD_MALLOC;
@@ -1694,7 +1702,7 @@ STATICforIDL CDFstatus ReadAEDRList (vFILE *fp,
       TempAEDR->Value = cdf_AllocateMemory(TempAEDR->ValueSize, NULL);
       if (TempAEDR->Value == NULL) return BAD_MALLOC;
       if (!READv(TempAEDR->Value,TempAEDR->ValueSize,1,fp)) return CRE;
-      LastAEDRNum = TempAEDR->AEDR.Num;
+      ++iEntries; 
       (*AEDRList)[TempAEDR->AEDR.Num] = TempAEDR;
   };
   return pStatus;
