@@ -296,6 +296,19 @@ else {
   if (!EndsWithIgCase(SKTpath, ".skt"))
     strcatX (SKTpath, ".skt", DU_MAX_PATH_LEN);
   ExpandPath (SKTpath, SKTpathX);
+
+/******************************************************************************
+* Display information.
+******************************************************************************/
+
+  WriteOut (stdout, "Making  a skeleton table from \"");
+  WriteOut (stdout, CDFpath);
+  if (!EndsWithIgCase(CDFpath, ".cdf"))
+    WriteOut (stdout, ".cdf");
+  WriteOut (stdout, "\"  to  \"");
+  WriteOut (stdout, SKTpath);
+  WriteOut (stdout, "\"...\n");
+
   SKTfp = fopen (SKTpathX, "w");
   if (SKTfp == NULL) {
     WriteOut (stdout, "Error creating skeleton table (");
