@@ -65,7 +65,7 @@ long compression, compressParms[CDF_MAX_DIMS], cPct;
 long numRecs, numAllocRecs, maxRec, sp, bf, maxAllocRec;
 long nHypers, hyperN, nValuesPerRec, nLogValuesPerRec, 
      nValuesPerDim[CDF_MAX_DIMS], nValues;
-char CDFpath[CDF_PATHNAME_LEN+1], outputCDF[CDF_PATHNAME_LEN+1];
+char CDFpath[CDF_PATHNAME_LEN+1], outputFile[CDF_PATHNAME_LEN+1];
 char CDFname[DU_MAX_NAME_LEN+1], dir[DU_MAX_DIR_LEN+1];
 char varName[CDF_VAR_NAME_LEN256+1], attrName[CDF_ATTR_NAME_LEN256+1];
 char copyRight[CDF_COPYRIGHT_LEN+1];
@@ -153,9 +153,9 @@ switch (argC) {
     * Check for `output' qualifier.
     ************************************************************************/
     if (qop->qualEntered[OUTPUTqual])
-      strcpyX (outputCDF, qop->qualOpt[OUTPUTqual], CDF_PATHNAME_LEN);
+      strcpyX (outputFile, qop->qualOpt[OUTPUTqual], CDF_PATHNAME_LEN);
     else
-      MakeNUL(outputCDF);
+      MakeNUL(outputFile);
     /************************************************************************
     * Check for `vars' qualifier.
     ************************************************************************/
@@ -185,30 +185,41 @@ switch (argC) {
       ParsePath (CDFpath, dir, CDFname);
     }
 
-    if (!NULstring(outputCDF)) {
-      if (strncmpIgCase(outputCDF, "source", 6) != 0) {
+    if (!NULstring(outputFile)) {
+      if (strncmpIgCase(outputFile, "source", 6) != 0) {
         int loc;
         char mytmp[CDF_PATHNAME_LEN+1];
         strcpy(mytmp, CDFpath);
         loc = StrlaststrIgCase(mytmp, ".cdf");
         if (loc == -1) strcatX (EofS(mytmp), ".txt", 0);
         else strcpyX (mytmp+loc, ".txt", 0);
-        strcpyX (outputCDF, mytmp, 0);
+        strcpyX (outputFile, mytmp, 0);
       } else {
-        ParsePath (outputCDF, oDir, oName);
-        if (strchr(oName,'.') == NULL) strcatX (outputCDF, ".txt", DU_MAX_PATH_LEN);
+        ParsePath (outputFile, oDir, oName);
+        if (strchr(oName,'.') == NULL) strcatX (outputFile, ".txt", DU_MAX_PATH_LEN);
       }
     }
   }
 
-  if (!strcmp(outputCDF, CDFpath)) {
+  /****************************************************************************
+  * Display information.
+  ****************************************************************************/
+  WriteOut (stdout, "Dumping cdf from \"");
+  WriteOut (stdout, CDFpath);
+  if (!EndsWithIgCase(CDFpath, ".cdf"))
+    WriteOut (stdout, ".cdf");
+  if (!NULstring(outputFile)) { 
+    WriteOut (stdout, "\"  to  \"");
+    WriteOut (stdout, outputFile);
+  }
+  WriteOut (stdout, "\"...\n");
+
+  if (!strcmp(outputFile, CDFpath)) {
       DisplayError ("Output file name is identical to source CDF file.");
       qopError = TRUE;
       return TRUE;
   }
 
-  fp = BOO(!NULstring(outputCDF),FOPEN(outputCDF,"w"),stdout);
-
   /****************************************************************************
   * Open/inquire CDF.
   ****************************************************************************/
@@ -235,6 +246,8 @@ switch (argC) {
                    NULL_);
   if (status < CDF_OK) QuitCDF ("2.0", status, CDFpath);
 
+  fp = BOO(!NULstring(outputFile),FOPEN(outputFile,"w"),stdout);
+
   /**********************************/
   /* Print out the file information */
   /**********************************/
