@@ -9,6 +9,9 @@
 *   V1.0  09-Jul-06, M Liu      Original version.
 *   V1.1  08-Mar-07, D Han      Fixed the bug with "cdfmerge -java" option.
 *                               Fixed the memory free problem (prefixes)
+*   V1.2  05-Aug-08, M Liu      Modified to handle variable "Epoch" 
+*                               differently from "Epoch_RANGE". "Epoch" is 
+*                               handled just like other variables.
 *
 ******************************************************************************/
 
@@ -98,7 +101,7 @@ static int  *inentries;
 static int lineAttrs = 0, lineEntries;
 static time_t bintim;
 static char generationDate[11];
-static errorP = 0;
+static int errorP = 0;
 
 /******************************************************************************
 * Main.
@@ -385,7 +388,7 @@ switch (argC) {
   /***************************************************************************
   * Display converting message.
   ***************************************************************************/
-  printf ("Merging \"");
+  printf ("Merging cdf files: \"");
   for (icount = 0; icount < numCDFs; icount++) {
     if (icount != 0) printf ("        \"");
     printf (CDFpaths[icount]);
@@ -400,7 +403,7 @@ switch (argC) {
       else
         printf ("\" \n");
   }
-  printf ("     to \"");
+  printf ("     into \"");
   printf (outputCDF);
   if (!EndsWithIgCase (outputCDF, ".cdf"))
     printf (".cdf");
@@ -541,11 +544,15 @@ switch (argC) {
                                                    FatalError);
         strcpyX (varNames[i], varName, strlen(varName));
 
+/*
         if ((strcmpIgCase (varName, "epoch") != 0) ||
             (strcmpIgCase (varName, "range_epoch") != 0)) {
+*/
+        if (strcmpIgCase (varName, "range_epoch") != 0) {
           if (first) {
             /*******************************************************/
-            /* Create variable "Epoch" or "RANGE_EPOCH".
+            /* Create variable "Epoch" or "RANGE_EPOCH". -- old
+            /* Create variable "RANGE_EPOCH".
             /*******************************************************/
             dimSizes[0] = 0L;
             dimVarys[0] = 0L;
@@ -692,9 +699,11 @@ switch (argC) {
 
               if (STRINGdataType(dataTypeX)) 
                 *(((char *)value)+numElemsX) = NUL;
-
+/*
               if ((strcmpIgCase (varName, "epoch") != 0) ||
                   (strcmpIgCase (varName, "range_epoch") != 0)) {
+*/
+              if (strcmpIgCase (varName, "range_epoch") != 0) {
 	          strcpyX (newVarName, varName, 0);
 	      } else {
                 if (usePrefix && !dataOnly)
@@ -786,8 +795,11 @@ switch (argC) {
                                                        value,
                                    NULL_);
                   if (status < CDF_OK) {
+/*
                     if ((strcmpIgCase (varName, "epoch") == 0) &&
                         (strcmpIgCase (varName, "range_epoch") == 0)) 
+*/
+                    if (strcmpIgCase (varName, "range_epoch") == 0) 
                       QuitCDF ("19.7", status, newVarName);
                   }
                 }
@@ -887,10 +899,14 @@ switch (argC) {
       if (maxRec == NO_RECORD) continue;
 
       /************************************************************************
-      * Acquire the min/max epoch time for Epoch or RANGE_EPOCH variable.
+      * Acquire the min/max epoch time for Epoch or RANGE_EPOCH variable. -old
+      * Acquire the min/max epoch time for RANGE_EPOCH variable, only.
       ************************************************************************/
+/*
       if ((strcmpIgCase (varName, "epoch") != 0) ||
           (strcmpIgCase (varName, "range_epoch") != 0)) {
+*/
+      if (strcmpIgCase (varName, "range_epoch") != 0) {
         
         status = CDFlib (SELECT_, zVAR_RECNUMBER_, 0L,
                                   zVAR_RECCOUNT_, 2L,
@@ -1867,8 +1883,11 @@ char *timeStamp;
 
     found = FALSE;
     for (iz = 0; iz < (int) numVars; iz++) {
+/*
       if ((strcmpIgCase (varNames[iz], "epoch") != 0) ||
           (strcmpIgCase (varNames[iz], "range_epoch") != 0)) {
+*/
+      if (strcmpIgCase (varNames[iz], "range_epoch") != 0) {
         iy = iz;
         found = TRUE;
         break;
@@ -2207,7 +2226,6 @@ void LoadgAttributes2 ()
       if (inentries[i] == -1)                                 
         lsi = TRUE;                                           
     }
-
     status = CDFlib (SELECT_, CDF_, ido,
                      CREATE_, ATTR_, attrs[i], GLOBAL_SCOPE, &attrNum,
                      NULL_);
@@ -2359,7 +2377,7 @@ char *masterFile;
   FILE *masterfp;
   int  i, maxAttr, maxEntry;
   char line[MAX_MERGELINE_LEN+1+1], item[MAX_MERGELINE_LEN+1];
-  char *ptr;
+  char *ptr, *ptr2;
   char **tmp;
   int  *tmp2;
   Logical ib;
@@ -2378,8 +2396,10 @@ char *masterFile;
     for (i = 0; line[i] != NUL; i++)
        if (line[i] == Nl) line[i] = '\0'; 
     RemoveLeadingBlanks (line);
+    RemoveTrailingBlanks (line);
     ptr = strchr (line, ':');
-    if (ptr != NULL && line[(int)strlen(line)-1] == ':') { 
+    ptr2 = strchr (line, ' ');
+    if (ptr != NULL && ptr2 == NULL && line[(int)strlen(line)-1] == ':') { 
       if (ib == TRUE) {
       /* No entry entered for the previous attribute... */
         inentries[lineAttrs-1] = -1;
@@ -2432,4 +2452,5 @@ char *masterFile;
   if (ib == TRUE) inentries[lineAttrs-1] = -1;
 
   fclose (masterfp);
+  return TRUE;
 }
