@@ -250,14 +250,25 @@ char *argV[];
     }
   }
   /****************************************************************************
-  * Open/inquire CDF.
+  * Display information.
   ****************************************************************************/
   ParsePath (CDFpath, CDFdir, CDFname);
   WriteOut (OUTfp, "Statistics for \"");
+  if (!NULstring(oSpec)) WriteOut (stdout, "Statistics for \"");
   WriteOut (OUTfp, CDFname);
+  if (!NULstring(oSpec)) WriteOut (stdout, CDFname);
   if (!EndsWithIgCase(CDFname, ".cdf"))
-    WriteOut (stdout, ".cdf");
+    WriteOut (OUTfp, ".cdf");
+    if (!NULstring(oSpec)) WriteOut (stdout, ".cdf");
+  if (!NULstring(oSpec)) {
+    WriteOut (stdout, "\"  to  \"");
+    WriteOut (stdout, oSpec);
+  }
   WriteOut (OUTfp, "\"...\n");
+  if (!NULstring(oSpec)) WriteOut (stdout, "\"...\n");
+  /****************************************************************************
+  * Open/inquire CDF.
+  ****************************************************************************/
   status = CDFlib (OPEN_, CDF_, CDFpath, &id,
 		   SELECT_, CDF_READONLY_MODE_, READONLYon,
 			    CDF_zMODE_, zMode,
